* Free software: MIT license

# dfns
A library to programmatically create, interact and automate your data pipelines in the most popular cloud plattforms.

### Installation
```
pip install dfns
```
### Documentation

https://dfns.technology

### Get started
How to call the different tools from dfns
```Python
from dfns import tools
dp = tools.data_processing_tools()
```
